"""Список русских стоп-слов."""

stop_words = [
    "а",
    "абсолютно",
    "аж",
    "более",
    "больше",
    "бы",
    "быстро",
    "в",
    "во",
    "ведь",
    "весь",
    "вместе",
    "вновь",
    "вовсе",
    "вообще",
    "вот",
    "впервые",
    "вполне",
    "впрочем",
    "временами",
    "временный",
    "всегда",
    "всего",
    "все-таки",
    "вчистую",
    "даже",
    "данный",
    "для",
    "до",
    "довольно",
    "довольно-таки",
    "долго",
    "долгий",
    "еще",
    "ж",
    "же",
    "за",
    "затем",
    "зато",
    "здесь",
    "и",
    "ибо",
    "или",
    "именно",
    "иногда",
    "к",
    "как-то",
    "какой-то",
    "классный",
    "конечно",
    "красивый",
    "кряду",
    "ли",
    "мало",
    "менее",
    "много",
    "мой",
    "на",
    "наверно",
    "наверное",
    "наш",
    "немало",
    "немного",
    "неплохой",
    "несколько",
    "никак",
    "никогда",
    "но",
    "ну",
    "ну-ка",
    "о",
    "об",
    "однако",
    "ой",
    "опять",
    "особо",
    "особенно",
    "от",
    "ох",
    "очень",
    "очередной",
    "перед",
    "плохой",
    "по",
    "под",
    "подробно",
    "подробный",
    "подряд",
    "поздний",
    "пока",
    "полностью",
    "постоянно",
    "потом",
    "почти",
    "при",
    "просто",
    "прямиком",
    "прямой",
    "пусть",
    "раз",
    "рано",
    "сам",
    "самый",
    "свой",
    "себя",
    "сей",
    "сейчас",
    "слишком",
    "снова",
    "совсем",
    "сразу",
    "стать",
    "так",
    "также",
    "такой",
    "там",
    "теперь",
    "то",
    "тогда",
    "тоже",
    "только",
    "тот",
    "тут",
    "уверенно",
    "увы",
    "уж",
    "уже",
    "ура",
    "хорошо",
    "хотя",
    "часто",
    "чуть",
    "это",
    "этот",
]



"""Подготовка русскоязычных текстов хоккейных новостей для обучения нейронных сетей."""

__version__ = "1.0.3"

from typing import Dict, List, Optional

from khl import preprocess, utils
from khl.stop_words import stop_words


def text_to_codes(
    text: str,
    lemmas_coder: Dict[preprocess.Lemma, preprocess.Code],
    stop_words_: Optional[List[preprocess.Lemma]] = stop_words,
    replace_ners_: bool = True,
    replace_dates_: bool = True,
    replace_penalties_: bool = True,
    exclude_unknown: bool = True,
    max_len: Optional[int] = None,
) -> List[preprocess.Code]:
    """
    Преобразует текст в последовательность кодов.

    args:
      text: текст новости
      lemmas_coder: словарь, в котором каждая лемма однозначно
        идентифицируется со своим целочисленным кодом
      stop_words_: стоп-слова для исключения
      replace_ners_: если True, то в тексте имена людей заменяются на
        слово 'per', названия команд заменяются на слово 'org',
        названия городов заменяются на слово 'loc'
      replace_dates_: если True, то в тексте даты заменяются на слово 'date'
      replace_penalties_: если True, то в тексте удаления вида '2+10'
        заменяются на слово 'pen'
      exclude_unknown: если True, то слова, которых нет в частотном словаре,
        отбрасываются; если False, то слова, которых нет в частотном словаре,
        заменяются на код неизвестного слова
      max_len: длина последовательности на выходе
    """
    text = utils.unify_text(text)
    text = utils.simplify_text(text, replace_ners_, replace_dates_, replace_penalties_)
    lemmas = preprocess.lemmatize(text, stop_words_)
    codes = preprocess.lemmas_to_codes(lemmas, lemmas_coder, exclude_unknown, max_len)
    return codes
